function Segment = CircleSeg45(Radius, AssignInitVal, OnChange)
% CircleSeg45 45degre circular segment of Radius radius 
%
% CircleSeg45 computes points on a 45 degree cirvular segment of Radius radius.
% AssignInitVal - use first value (Radius) as the first point
% OnChange - record every point/record points only on change of the other
% coordinate
% 
% Outputs: 
% Segment - vector of points on a circular segment with x spaced by 1
%
% Author Jan Schier <schier@utia.cas.cz>
% Date 2009/08/04
% 
% Copyright
% (c) 2009 Dept. of Signal Processing
% Institute of Information Theory and Automation
% Academy of Sciences of the Czech Republic, Prague
%
% http://sp.utia.cz
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% You are free to distribute this software under Version 2.1
% of the GNU General Public License.

    xr = 0;
    yr = round(Radius);
    d = 5/4-yr;
    tmp = yr;
    if AssignInitVal
        Segment = yr;
    else
        Segment = [];
    end
    while xr <= yr
        [xrn, yr, d, change] = CircUpdate(xr, yr, d);
        if OnChange 
            if change
                Segment(end+1) = xr;
            end
        else
            Segment(end+1) = yr;
        end
        xr = xrn;
    end
end